@@ -7,7 +7,7 @@ from instant.producers import publish
 
 class InstantTestProducers(InstantBaseTest):
     def test_publish(self):
-        with self.assertRaises(ValueError):
+        with self.settings(CENTRIFUGO_API_KEY=None) and self.assertRaises(ValueError):
             publish("chan")
         with self.assertRaises(CentException):
             publish("chan", "message")
